@@ -3,7 +3,7 @@
 //                              -----------------                             *
 //  Description : The main application class. It all begins here.             *
 //  Started     : 15/08/2003                                                  *
-//  Last Update : 14/11/2006                                                  *
+//  Last Update : 05/02/2010                                                  *
 //  Copyright   : (C) 2003 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -44,7 +44,7 @@
 
 //*****************************************************************************
 
-class AppGSpiceUI : public wxApp
+class App_gSpiceUI : public wxApp
 {
   private:
 
@@ -53,8 +53,8 @@ class AppGSpiceUI : public wxApp
 
   public:
 
-    AppGSpiceUI( void );
-   ~AppGSpiceUI( );
+    App_gSpiceUI( void );
+   ~App_gSpiceUI( );
 
     virtual  bool  OnInit  ( void );
 //  virtual  int   MainLoop( void );
