@@ -2,7 +2,7 @@
 //                                CmdLinePcr.cpp                              *
 //                               ----------------                             *
 //  Started     : 22/02/2005                                                  *
-//  Last Update : 12/10/2009                                                  *
+//  Last Update : 15/03/2010                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -242,7 +242,7 @@ bool  CmdLinePcr::bProcOption_s( int * piArg )
   osArg = m_ppsArgV[ *piArg ];
   osArg.MakeUpper( );
 
-  if(      wxString( wxT("GNUCAP") ) .StartsWith( osArg ) ) osArg = CLP_GNUCAP;
+  if(      wxString( wxT("GNUCAP")  ).StartsWith( osArg ) ) osArg = CLP_GNUCAP;
   else if( wxString( wxT("NGSPICE") ).StartsWith( osArg ) ) osArg = CLP_NGSPICE;
   else
   {
@@ -303,8 +303,8 @@ bool  CmdLinePcr::bProcOption_w( int * piArg )
   osArg = m_ppsArgV[ *piArg ];
   osArg.MakeUpper( );
 
-  if(      wxString( wxT("GWAVE") ).StartsWith( osArg ) ) osArg = CLP_GWAVE;
-  else if( wxString( wxT("GAW") )  .StartsWith( osArg ) ) osArg = CLP_GAW;
+  if(      wxString(CLP_GWAVE).Upper().StartsWith( osArg ) ) osArg = CLP_GWAVE;
+  else if( wxString(CLP_GAW  ).Upper().StartsWith( osArg ) ) osArg = CLP_GAW;
   else
   {
     std::cout << "Invalid waveform viewer specifier : "
@@ -318,7 +318,54 @@ bool  CmdLinePcr::bProcOption_w( int * piArg )
 }
 
 //*****************************************************************************
-// Process schematic file name command line argument/s.
+// Do general checks of arguments which should be file names. If any of the
+// args. is not a valid file name display an error message and return FALSE.
+//
+// Argument List :
+//   piArg - A pointer to the current command line argument
+//           (incremented as part of processing)
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdLinePcr::bCheckFiles( int * piArg )
+{
+  wxFileName  ofn1;
+  wxString    os1;
+  int         i1;
+
+  // Check the validity of the file name/s
+  for( i1=*piArg; i1<m_iArgC; i1++ )
+  {
+    ofn1 = wxString( m_ppsArgV[ i1 ], *wxConvCurrent );
+
+    if( ! ofn1.IsOk( ) )
+    {
+      os1 = m_ppsArgV[ i1 ];
+      std::cout << "Invalid file name : " << os1.mb_str( ) << '\n';
+
+      return( FALSE );
+    }
+
+    if( ! ofn1.FileExists( ) )
+    {
+      os1 = m_ppsArgV[ i1 ];
+      std::cout << "File doesn't exist : " << os1.mb_str( ) << '\n';
+
+      return( FALSE );
+    }
+  }
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Attempt to process the remaining command line argument/s as schematic file
+// name/s.
+// If a Guile procedure has been specified the command line argument/s will be
+// treated as schematic file names. If no Guile procedure has been specified
+// the decision will be made based on file name extensions.
 //
 // Argument List :
 //   piArg - A pointer to the current command line argument
@@ -331,34 +378,30 @@ bool  CmdLinePcr::bProcOption_w( int * piArg )
 bool  CmdLinePcr::bProcSchems( int * piArg )
 {
   wxFileName  ofn1;
-  wxString    os1;
+  int         i1;
 
-  // Check that there are enough arguments
-  if( *piArg >= m_iArgC )
+  // Check that there are unprocessed command line argument/s
+  if( *piArg >= m_iArgC ) return( FALSE );
+
+  // If no Guile procedure has been specified test the file name extensions
+  if( m_osGuileProc.IsEmpty( ) )
   {
-    std::cout << "Missing schematic file name/s.\n";
-    return( FALSE );
+    for( i1=*piArg; i1<m_iArgC; i1++ )
+    {
+      ofn1 = wxString( m_ppsArgV[ i1 ], *wxConvCurrent );
+
+      if( ofn1.GetExt( ).Upper( ) != wxT("SCH") ) return( FALSE );
+    }
   }
 
-  // Check the validity of the file name/s
+  // Load the schematic file name/s into m_osaSchemFiles
   while( *piArg < m_iArgC )
   {
     ofn1 = wxString( m_ppsArgV[ *piArg ], *wxConvCurrent );
-    if( ! ofn1.IsOk( ) )
-    {
-      os1 = m_ppsArgV[ *piArg ];
-      std::cout << "Invalid schematic file name : " << os1.mb_str( ) << '\n';
-      return( FALSE );
-    }
-    if( ! ofn1.FileExists( ) )
-    {
-      os1 = m_ppsArgV[ *piArg ];
-      std::cout << "Schematic file doesn't exist : " << os1.mb_str( ) << '\n';
-      return( FALSE );
-    }
+
     if( ofn1.IsRelative( ) ) ofn1.MakeAbsolute( );
 
-    m_oasSchemFiles.Add( ofn1.GetFullPath( ) );
+    m_osaSchemFiles.Add( ofn1.GetFullPath( ) );
 
     ( *piArg )++;
   }
@@ -367,7 +410,7 @@ bool  CmdLinePcr::bProcSchems( int * piArg )
 }
 
 //*****************************************************************************
-// Process netlist file name command line argument.
+// Attempt to process a command line argument as a netlist file name.
 //
 // Argument List :
 //   piArg - A pointer to the current command line argument
@@ -380,35 +423,19 @@ bool  CmdLinePcr::bProcSchems( int * piArg )
 bool  CmdLinePcr::bProcNetList( int * piArg )
 {
   wxFileName  ofn1;
-  wxString    os1;
 
-  // Check that there are enough arguments
-  if( *piArg >= m_iArgC )
-  {
-    std::cout << "Missing netlist file name.\n";
-    return( FALSE );
-  }
+  // Check that there are unprocessed command line argument/s
+  if( *piArg >= m_iArgC ) return( FALSE );
 
-  // Check the validity of the file name
+  // Load the netlist file name into m_osNetLstFile
   ofn1 = wxString( m_ppsArgV[ *piArg ], *wxConvCurrent );
-  if( ! ofn1.IsOk( ) )
-  {
-    os1 = m_ppsArgV[ *piArg ];
-    std::cout << "Invalid netlist file name : " << os1.mb_str( ) << '\n';
-    return( FALSE );
-  }
-  if( ! ofn1.FileExists( ) )
-  {
-    os1 = m_ppsArgV[ *piArg ];
-    std::cout << "Netlist file doesn't exist : " << os1.mb_str( ) << '\n';
-    return( FALSE );
-  }
+
   if( ofn1.IsRelative( ) ) ofn1.MakeAbsolute( );
 
-  ( *piArg )++;
-
   m_osNetLstFile = ofn1.GetFullPath( );
 
+  ( *piArg )++;
+
   return( TRUE );
 }
 
@@ -435,7 +462,7 @@ void  CmdLinePcr::Usage( void )
       << wxT("                      SIMENG = gnucap (default) or ngspice\n")
       << wxT("          -a ANA    : Specify the analysis page to be displayed\n")
       << wxT("                      ANA    = op, dc (default), ac, tr, fo, di, no, pz, se or tf\n")
-      << wxT("          -g [PROC] : Guile procedure to import a schematic file using gNetList\n")
+      << wxT("          -g [PROC] : Guile procedure for importing a schematic file with gNetList\n")
       << wxT("                      PROC   = spice-sdb (default), pcb, protelii, verilog, etc.\n")
       << wxT("          -w VIEWER : Specify the waveform viewer to be used\n")
       << wxT("                      VIEWER = gwave (default) or gaw\n")
@@ -513,15 +540,19 @@ void  CmdLinePcr::SetConfig( void )
   {
     poCfg->SetPath( wxT("/Files") );
     poCfg->Write( wxT("NetList"), m_osNetLstFile );
+
+    poCfg->Write( wxT("Schematics"), wxT("") );
   }
 
   // Set the schematic file name/s
-  if( ! m_oasSchemFiles.IsEmpty( ) )
+  if( ! m_osaSchemFiles.IsEmpty( ) )
   {
     poCfg->SetPath( wxT("/Files") );
-    for( i1=0, os1.Empty( ); i1<(int)m_oasSchemFiles.GetCount( ); i1++ )
-      os1 << m_oasSchemFiles.Item( i1 ) << wxT(' ');
+    for( i1=0, os1.Empty( ); i1<(int)m_osaSchemFiles.GetCount( ); i1++ )
+      os1 << m_osaSchemFiles.Item( i1 ) << wxT(' ');
     poCfg->Write( wxT("Schematics"), os1 );
+
+    poCfg->Write( wxT("NetList"), wxT("") );
   }
 
   // Write any changes to file
@@ -587,7 +618,8 @@ bool  CmdLinePcr::bClear( void )
   m_osViewer     .Empty( );
   m_osConfigFile .Empty( );
   m_osNetLstFile .Empty( );
-  m_oasSchemFiles.Empty( );
+  m_osaSchemFiles.Empty( );
+
   m_bCleanCfgFile = FALSE;
 
   return( TRUE );
@@ -636,7 +668,7 @@ bool  CmdLinePcr::bProcArgs( void )
   for( iArg=1, osArg=m_ppsArgV[1]; iArg<m_iArgC; ++iArg, osArg=m_ppsArgV[iArg] )
   {
     if( osArg.GetChar( 0 )=='-' && osArg.Length( )>2 )
-    { // Concatenated options
+    { // Found concatenated options --> error
       std::cout << "Options must be specfied separately : " << osArg.mb_str( ) << '\n';
       return( FALSE );
     }
@@ -673,32 +705,26 @@ bool  CmdLinePcr::bProcArgs( void )
       if( ! bProcOption_w( &iArg ) ) return( FALSE );
     }
     else if( osArg.GetChar( 0 ) == wxT('-') )
-    { // Invalid option
+    { // Found invalid option --> error
       std::cout << "Invalid option : " << osArg.mb_str( ) << '\n';
       return( FALSE );
-    }
+    } // The argument is not an option
     else break;
   }
 
-  // Process file names
-  if( ! m_osGuileProc.IsEmpty( ) )
-  {
-    if( ! bProcSchems( &iArg ) )     return( FALSE );
-    iArg++;
-  }
-  else if( iArg < m_iArgC )
-  {
-    if( ! bProcNetList( &iArg ) )    return( FALSE );
-    iArg++;
-  }
+  // Attempt to process any remaining argument/s as file name/s
+  if( ! bCheckFiles( &iArg ) )       return( FALSE );
+  bProcSchems ( &iArg );
+  bProcNetList( &iArg );
 
-  // Check that all arguments have been processed
+  // At this stage all arguments should have been processed
   if( iArg < m_iArgC )
   {
     os1 << wxT("Too many arguments :");
     for( osArg=m_ppsArgV[ iArg ]; iArg<m_iArgC; osArg=m_ppsArgV[ ++iArg ] )
       os1 << wxT(' ') << osArg;
     std::cout << os1.mb_str( ) << '\n';
+
     return( FALSE );
   }
 
@@ -712,10 +738,64 @@ bool  CmdLinePcr::bProcArgs( void )
     return( FALSE );
   }
 
-  // All's well so display the system banner on the console
+  // All's well so display the system banner
   Version( );
 
   return( TRUE );
 }
 
 //*****************************************************************************
+// Print the object attributes.
+//
+// Argument List :
+//   rosPrefix - A prefix to every line displayed (usually just spaces)
+
+void  CmdLinePcr::Print( const wxString & rosPrefix )
+{
+  wxString  osPrefix, os1;
+  int       i1;
+
+  osPrefix = rosPrefix + wxT( "CmdLinePcr::" );
+
+  std::cout << osPrefix .mb_str( ) << "m_iArgC            : "
+       << m_iArgC << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_ppsArgV          :";
+  for( i1=0; i1<m_iArgC; i1++ )
+  {
+    os1 = m_ppsArgV[ i1 ];
+    std::cout << ' ' << os1.mb_str( );
+  }
+  std::cout << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osSimrType       : "
+       << m_osSimrType  .mb_str( ) << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osAnaType        : "
+       << m_osAnaType   .mb_str( ) << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osGuileProc      : "
+       << m_osGuileProc .mb_str( ) << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osViewer         : "
+       << m_osViewer    .mb_str( ) << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osConfigFile     : "
+       << m_osConfigFile.mb_str( ) << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osNetLstFile     : "
+       << m_osNetLstFile.mb_str( ) << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_osaSchemFiles[ ] : ";
+  for( i1=0; i1<(int)m_osaSchemFiles.GetCount( ); i1++ )
+  {
+    if( i1 > 0 ) cout << ", ";
+    std::cout << m_osaSchemFiles.Item( i1 ).mb_str( );
+  }
+  std::cout << '\n';
+
+  std::cout << osPrefix .mb_str( ) << "m_bCleanCfgFile    : "
+            << (m_bCleanCfgFile ? "TRUE" : "FALSE") << '\n';
+}
+
+//*****************************************************************************
