@@ -124,8 +124,8 @@ void  CmdBase::Print( const wxString & rosPrefix )
   cout << rosPrefix .mb_str( ) << "wxString::"
        << this     ->mb_str( ) << '\n';
 
-  cout << rosPrefix .mb_str( ) << "m_osErrMsg : "
-       << m_osErrMsg.mb_str( ) << '\n';
+  cout << rosPrefix .mb_str( ) << "m_osErrMsg : \""
+       << m_osErrMsg.mb_str( ) << "\"\n";
 
   cout << rosPrefix .mb_str( ) << "m_eSimEng  : ";
   switch( m_eSimEng )
