@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                                NbkSimrBase.hpp                             *
 //                               -----------------                            *
-//  Description : Base class for all simulator notebooks which contains the   *
-//                individual analysis panels.                                 *
-//  Started     : 05/05/2004                                                  *
-//  Last Update : 19/08/2009                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : Base class for all simulator notebooks which contains the    *
+//               individual analysis panels.                                  *
+// Started     : 05/05/2004                                                   *
+// Last Update : 12/04/2010                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -75,6 +75,12 @@ class NbkSimrBase : public wxNotebook
                                      { if( bIsOk( ) ) m_osErrMsg = rosErrMsg; }
 
     eSimrType  eGetSimEng( void ) { return( m_eSimEng ); }
+
+    // Event handlers
+    void  OnPageChanged( wxNotebookEvent & roEvtNbk );
+
+    // Leave this as the last line as private access is envoked by macro
+    DECLARE_EVENT_TABLE( )
 };
 
 //*****************************************************************************
