@@ -4,7 +4,7 @@
 // Description : This class derives from the wxPanel class and provides a     *
 //               base class for all analysis panel classes.                   *
 // Started     : 26/04/2004                                                   *
-// Last Update : 19/08/2009                                                   *
+// Last Update : 12/04/2010                                                   *
 // Copyright   : (C) 2004 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -106,6 +106,11 @@ class PnlAnaBase : public wxPanel
     eSimrType    m_eSimEng;
     eCmdType     m_eAnaType;
 
+    // Flag to enable or disable sweep source synchronization
+    static  bool  m_bSyncSwpSrcs;
+    // The last sweep source selected by the user
+    static  Component  m_tCpntSwpSrcs;
+
     // Functions to create the display objects
     void  CreateBase  ( void );
     void  CreateScale ( void );
@@ -133,14 +138,18 @@ class PnlAnaBase : public wxPanel
     bool  bSetSimrEng( eSimrType eSimrEng );
     bool  bSetAnaType( eCmdType  eAnaType );
 
-    eSimrType  eGetSimrEng( void ) { return( m_eSimEng ); }
+    eSimrType  eGetSimrEng( void ) { return( m_eSimEng  ); }
     eCmdType   eGetAnaType( void ) { return( m_eAnaType ); }
 
+    static  void  SetSyncSwpSrcs( bool bEnable ) { m_bSyncSwpSrcs = bEnable; }
+
+    // Get or set the error message
     const wxString & rosGetErrMsg( void ) { return( m_osErrMsg ); }
           void          SetErrMsg( const wxString & rosErrMsg )
                                      { if( bIsOk( ) ) m_osErrMsg = rosErrMsg; }
 
-    friend  class  FrmMain;
+//    friend  class  FrmMain;
+    friend  class  NbkSimrBase;
     friend  class  NbkGnuCap;
     friend  class  NbkNgSpice;
 
@@ -178,6 +187,12 @@ class PnlAnaBase : public wxPanel
       ID_FST = ID_PNL_START,
       ID_LST = ID_PNL_TEMP
     };
+
+    // Event handlers
+    void  OnSrcName( wxCommandEvent & roEvtCmd );
+
+    // Leave this as the last line as private access is envoked by macro
+    DECLARE_EVENT_TABLE( )
 };
 
 //*****************************************************************************
