@@ -2,7 +2,7 @@
 //                               CmdGnuCapAC.cpp                              *
 //                              -----------------                             *
 // Started     : 21/02/2008                                                   *
-// Last Update : 14/10/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2008 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -285,7 +285,7 @@ void  CmdGnuCapAC::Print( const wxString & rosPrefix )
 //                                                                            *
 //*****************************************************************************
 
-#ifdef TEST_UTIL
+#ifdef TEST_CMDGCPAC
 
 // System include files
 
@@ -360,6 +360,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_UTIL
+#endif // TEST_CMDGCPAC
 
 //*****************************************************************************
