@@ -2,7 +2,7 @@
 //                              CmdGnuCapDC.cpp                               *
 //                             -----------------                              *
 // Started     : 29/01/2008                                                   *
-// Last Update : 14/10/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2008 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -289,7 +289,7 @@ void  CmdGnuCapDC::Print( const wxString & rosPrefix )
 //                                                                            *
 //*****************************************************************************
 
-#ifdef TEST_UTIL
+#ifdef TEST_CMDGCPDC
 
 // System include files
 
@@ -365,6 +365,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_UTIL
+#endif // TEST_CMDGCPDC
 
 //*****************************************************************************
