@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the GNU-Cap       *
 //               DC command. It inherits from the class CmdBase.              *
 // Started     : 29/01/2008                                                   *
-// Last Update : 13/05/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2008 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -18,8 +18,8 @@
 //                                                                            *
 //*****************************************************************************
 
-#ifndef CMDGNUCAPDC_HPP
-#define CMDGNUCAPDC_HPP
+#ifndef CMDGCPDC_HPP
+#define CMDGCPDC_HPP
 
 // System Includes
 
@@ -75,4 +75,4 @@ struct CmdGnuCapDC : public CmdBase
 
 //*****************************************************************************
 
-#endif // CMDGNUCAPDC_HPP
+#endif // CMDGCPDC_HPP
