@@ -2,7 +2,7 @@
 //                              CmdGnuCapOPT.cpp                              *
 //                             ------------------                             *
 // Started     : 11/09/2006                                                   *
-// Last Update : 19/08/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -616,7 +616,7 @@ void  CmdGnuCapOPT::Print( const wxString & rosPrefix )
 //                                                                            *
 //*****************************************************************************
 
-#ifdef TEST_UTIL
+#ifdef TEST_CMDGCPOPT
 
 // System include files
 
@@ -741,6 +741,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_UTIL
+#endif // TEST_CMDGCPOPT
 
 //*****************************************************************************
