@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the GNU-Cap       *
 //               OPTIONS command. It inherits from the class CmdBase.         *
 // Started     : 11/09/2006                                                   *
-// Last Update : 13/05/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -18,8 +18,8 @@
 //                                                                            *
 //*****************************************************************************
 
-#ifndef CMDGNUCAPOPT_HPP
-#define CMDGNUCAPOPT_HPP
+#ifndef CMDGCPOPT_HPP
+#define CMDGCPOPT_HPP
 
 // System Includes
 
@@ -164,4 +164,4 @@ struct CmdGnuCapOPT : public CmdBase
 
 //*****************************************************************************
 
-#endif // CMDGNUCAPOPT_HPP
+#endif // CMDGCPOPT_HPP
