@@ -2,7 +2,7 @@
 //                              DlgGcpCfgOPT.cpp                              *
 //                             ------------------                             *
 //  Started     : 14/09/2006                                                  *
-//  Last Update : 10/06/2009                                                  *
+//  Last Update : 23/02/2010                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -895,7 +895,10 @@ void  DlgGcpCfgOPT::OnBtnOk( wxCommandEvent & roEvtCmd )
 
 void  DlgGcpCfgOPT::OnBtnDefaults( wxCommandEvent & roEvtCmd )
 {
-  bClear( );
+  CmdGnuCapOPT  oCmdOPT;
+
+  oCmdOPT.bClear( );
+  SetValues( oCmdOPT );
 }
 
 //*****************************************************************************
