@@ -2,7 +2,7 @@
 //                              PnlGnuCapDC.cpp                               *
 //                             -----------------                              *
 // Started     : 18/08/2003                                                   *
-// Last Update : 07/09/2009                                                   *
+// Last Update : 13/04/2010                                                   *
 // Copyright   : (C) 2003 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -68,8 +68,7 @@ void  PnlGnuCapDC::Create( void )
   m_oRbxScale.Enable( eSCALE_OCT, FALSE );
 
   // Create and add input source
-  new wxStaticText( this, ID_UNUSED, wxT("Signal Source"),
-                    wxPoint( 18, 176 ) );
+  new wxLabel( this, ID_UNUSED, wxT("Signal Source"), wxPoint( 18, 176 ) );
   m_oChoSrcName.Create( this, ID_CHO_SRCNAME,
                         wxPoint( 144, 171 ), wxSize( 110, 29 ) );
 
@@ -314,6 +313,9 @@ void  PnlGnuCapDC::OnScale( wxCommandEvent & roEvtCmd )
 void  PnlGnuCapDC::OnSrcName( wxCommandEvent & roEvtCmd )
 {
   InitSwpUnits( );
+
+  // Permit the base class to process this event as well
+  roEvtCmd.Skip( );
 }
 
 //*****************************************************************************
