@@ -2,7 +2,7 @@
 //                              PnlGnuCapOP.cpp                               *
 //                             -----------------                              *
 // Started     : 06/11/2003                                                   *
-// Last Update : 20/08/2009                                                   *
+// Last Update : 13/04/2010                                                   *
 // Copyright   : (C) 2003 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -245,15 +245,20 @@ void  PnlGnuCapOP::OnScale( wxCommandEvent & roEvtCmd )
 
 void  PnlGnuCapOP::OnSrcName( wxCommandEvent & roEvtCmd )
 {
-  Component  oCpnt;
+  wxString  os1;
 
-  oCpnt = m_oChoSrcName.GetStringSelection( );
-  m_oPnlSrcLvl.bSetUnitsType( oCpnt.eGetUnitsType( ) );
+  // Set the units type
+  os1 = m_oChoSrcName.GetStringSelection( );
+  m_oPnlSrcLvl.bSetUnitsType( Component::eGetUnitsType( os1 ) );
 
+  // Set the source value
   if( m_oChoSrcName.GetStringSelection( ) == wxT("None") )
     m_oPnlSrcLvl.bSetValue( (double) 0.0 );
   else if( m_oPnlSrcLvl.dfGetValue( ) == 0.0 )
     m_oPnlSrcLvl.bSetValue( (double) 1.0 );
+
+  // Permit the base class to process this event as well
+  roEvtCmd.Skip( );
 }
 
 //*****************************************************************************
