@@ -3,7 +3,7 @@
 //                               --------------                               *
 //  Description : This dialogue is used to enter applications preferences.    *
 //  Started     : 17/10/2006                                                  *
-//  Last Update : 18/09/2009                                                  *
+//  Last Update : 16/04/2010                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -50,14 +50,15 @@ class DlgPrefs : public wxDialog
     wxConfig    * m_poCfg;
 
     // Display controls
-    wxStaticText  m_oLblViewer;
-    wxChoice      m_oChoViewer;
-    wxStaticText  m_oLblTmpFileMgt;
-    wxChoice      m_oChoTmpFileMgt;
-    wxStaticText  m_oLblPrecision;
-    wxChoice      m_oChoPrecision;
-    PnlValue      m_oPnlMaxLines;
-    wxCheckBox    m_oCbxToolTips;
+    wxLabel     m_oLblViewer;
+    wxChoice    m_oChoViewer;
+    wxLabel     m_oLblTmpFileMgt;
+    wxChoice    m_oChoTmpFileMgt;
+    wxLabel     m_oLblPrecision;
+    wxChoice    m_oChoPrecision;
+    PnlValue    m_oPnlNbkMaxLines;
+    wxCheckBox  m_oCbxSyncSwpSrcs;
+    wxCheckBox  m_oCbxToolTips;
 
     // Button controls
     wxButton      m_oBtnOk;
@@ -79,15 +80,17 @@ class DlgPrefs : public wxDialog
 
     bool  bClear( void );
 
-    const  wxString  rosGetViewer    ( void )
+    const  wxString  rosGetViewer     ( void )
                               { return( m_oChoViewer.GetStringSelection( ) ); }
-           int         iGetMaxLines  ( void )
-                              { return( (int) m_oPnlMaxLines.liGetValue( ) ); }
-           int         iGetTmpFileMgt( void )
+           int         iGetNbkMaxLines( void )
+                              { return( (int)m_oPnlNbkMaxLines.liGetValue()); }
+           int         iGetTmpFileMgt ( void )
                               { return( m_oChoTmpFileMgt.GetSelection( )   ); }
            int         iGetPrecision ( void )
                               { return( m_oChoPrecision.GetSelection( )    ); }
-           bool        bGetToolTips  ( void )
+           bool        bGetSyncSwpSrcs( void )
+                              { return( m_oCbxSyncSwpSrcs.IsChecked( )     ); }
+           bool        bGetToolTips   ( void )
                               { return( m_oCbxToolTips.IsChecked( )        ); }
 
     // Event handlers
@@ -105,8 +108,9 @@ class DlgPrefs : public wxDialog
       ID_CHO_TMPFILEMGT,
       ID_CHO_PRECISION,
 
-      ID_PNL_MAXLINES,
+      ID_PNL_NBKMAXLINES,
 
+      ID_CBX_SYNCSWPSRCS,
       ID_CBX_TOOLTIPS,
 
       ID_BTN_OK,
