@@ -2,7 +2,7 @@
 //                                FrmMain.cpp                                 *
 //                               -------------                                *
 //  Started     : 18/08/2003                                                  *
-//  Last Update : 12/10/2009                                                  *
+//  Last Update : 14/04/2010                                                  *
 //  Copyright   : (C) 2003 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -49,8 +49,8 @@ BEGIN_EVENT_TABLE( FrmMain, wxFrame )
   EVT_MENU( ID_MNU_CREATE,  FrmMain::OnSimCreate )
   EVT_MENU( ID_MNU_RUN,     FrmMain::OnSimRun    )
   EVT_MENU( ID_MNU_STOP,    FrmMain::OnSimStop   )
-  EVT_MENU( ID_MNU_EDIT,    FrmMain::OnEditSchem )
-  EVT_MENU( ID_MNU_PLOT,    FrmMain::OnViewData  )
+  EVT_MENU( ID_MNU_SCHEM,   FrmMain::OnSchematic )
+  EVT_MENU( ID_MNU_VIEWER,  FrmMain::OnViewData  )
   EVT_MENU( ID_MNU_GNUCAP,  FrmMain::OnSelSimEng )
   EVT_MENU( ID_MNU_NGSPICE, FrmMain::OnSelSimEng )
   EVT_MENU( ID_MNU_PREFS,   FrmMain::OnPrefs     )
@@ -64,13 +64,13 @@ BEGIN_EVENT_TABLE( FrmMain, wxFrame )
   EVT_TOOL( ID_TBR_CREATE,  FrmMain::OnSimCreate )
   EVT_TOOL( ID_TBR_RUN,     FrmMain::OnSimRun    )
   EVT_TOOL( ID_TBR_STOP,    FrmMain::OnSimStop   )
-  EVT_TOOL( ID_TBR_EDIT,    FrmMain::OnEditSchem )
-  EVT_TOOL( ID_TBR_PLOT,    FrmMain::OnViewData  )
+  EVT_TOOL( ID_TBR_SCHEM,   FrmMain::OnSchematic )
+  EVT_TOOL( ID_TBR_VIEWER,  FrmMain::OnViewData  )
   EVT_TOOL( ID_TBR_HELP,    FrmMain::OnManual    )
 
-  EVT_TOOL_ENTER( -1, FrmMain::OnTbrEnter )
+  EVT_TOOL_ENTER( -1,       FrmMain::OnToolEnter )
 
-  EVT_CLOSE( FrmMain::OnSysExit )
+  EVT_CLOSE(                FrmMain::OnSysExit   )
 
 END_EVENT_TABLE( )
 
@@ -118,6 +118,8 @@ FrmMain::~FrmMain( )
 
 void  FrmMain::Initialize( void )
 {
+  long  li1;
+
   // This line just suppresses the following compiler warning :
   //   ./icons/gspiceui-32x32.xpm:3: warning: gspiceui_xpm defined but not used
   char  c1; c1 = gspiceui_xpm[ 0 ][ 0 ]; // ???
@@ -130,6 +132,9 @@ void  FrmMain::Initialize( void )
   // Automatically update the frame layout when it is resized
   SetAutoLayout( TRUE );
 
+  // Initialize the FileTasks object eg. load schematic or netlist file/s
+  m_oFileTsks.Initialize( );
+
   // Call all the initialization functions
   InitMenuBar ( );
   InitToolBar ( );
@@ -142,8 +147,10 @@ void  FrmMain::Initialize( void )
   DoLayout( );
   InitPosnSize( );
 
-  // Initialize the FileTasks object eg. load schematic or netlist file
-  m_oFileTsks.Initialize( );
+  // Set the sweep source synchronization flag
+  m_poCfg->SetPath( wxT("/Main") );
+  m_poCfg->Read( wxT("SyncSwpSrcs"), &li1, 0 );
+  PnlAnaBase::SetSyncSwpSrcs( li1 != 0 ? TRUE : FALSE ); // ???
 
   // Display the desired analysis page
   m_poCfg->SetPath( wxT("/Simulator") );
@@ -181,38 +188,38 @@ void  FrmMain::InitMenuBar( void )
   poMenuBar->SetFont( FONT_NORM );
 
   // Load the menus with items
-  poMenuFile->Append( ID_MNU_OPEN,             wxT(" &Open ... ")         );
-  poMenuFile->Append( ID_MNU_IMPORT,           wxT(" &Import ... ")       );
-  poMenuFile->Append( ID_MNU_RELOAD,           wxT(" &Reload ")           );
-  poMenuFile->Append( ID_MNU_CLOSE,            wxT(" &Close ")            );
+  poMenuFile->Append( ID_MNU_OPEN,             wxT(" &Open ... ")        );
+  poMenuFile->Append( ID_MNU_IMPORT,           wxT(" &Import ... ")      );
+  poMenuFile->Append( ID_MNU_RELOAD,           wxT(" &Reload ")          );
+  poMenuFile->Append( ID_MNU_CLOSE,            wxT(" &Close ")           );
   poMenuFile->AppendSeparator( );
-  poMenuFile->Append( ID_MNU_EXIT,             wxT(" E&xit ")             );
+  poMenuFile->Append( ID_MNU_EXIT,             wxT(" E&xit ")            );
 
-  poMenuSimu->Append( ID_MNU_CREATE,           wxT(" &Create ")           );
-  poMenuSimu->Append( ID_MNU_RUN,              wxT(" &Run ")              );
-  poMenuSimu->Append( ID_MNU_STOP,             wxT(" &Stop ")             );
+  poMenuSimu->Append( ID_MNU_CREATE,           wxT(" &Create ")          );
+  poMenuSimu->Append( ID_MNU_RUN,              wxT(" &Run ")             );
+  poMenuSimu->Append( ID_MNU_STOP,             wxT(" &Stop ")            );
   poMenuSimu->AppendSeparator( );
-  poMenuSimu->Append( ID_MNU_EDIT,             wxT(" &Edit Schem ... ")   );
-  poMenuSimu->Append( ID_MNU_PLOT,             wxT(" &View Results ... ") );
+  poMenuSimu->Append( ID_MNU_SCHEM,            wxT(" Sc&hematic ... ")   );
+  poMenuSimu->Append( ID_MNU_VIEWER,           wxT(" &Data Viewer ... ") );
 
-  poMenuSets->AppendRadioItem( ID_MNU_GNUCAP,  wxT("  &GNU-Cap ")         );
-  poMenuSets->AppendRadioItem( ID_MNU_NGSPICE, wxT("  &NG-Spice ")        );
+  poMenuSets->AppendRadioItem( ID_MNU_GNUCAP,  wxT("  &GNU-Cap ")        );
+  poMenuSets->AppendRadioItem( ID_MNU_NGSPICE, wxT("  &NG-Spice ")       );
   poMenuSets->AppendSeparator( );
-  poMenuSets->Append( ID_MNU_PREFS,            wxT("&Preferences ... ")   );
+  poMenuSets->Append( ID_MNU_PREFS,            wxT("&Preferences ... ")  );
 
-  poMenuHelp->Append( ID_MNU_MANUAL,           wxT(" &Manual ... ")       );
+  poMenuHelp->Append( ID_MNU_MANUAL,           wxT(" &User Manual ... ") );
   poMenuHelp->AppendSeparator( );
-  poMenuHelp->Append( ID_MNU_ABOUT,            wxT(" &About ... ")        );
+  poMenuHelp->Append( ID_MNU_ABOUT,            wxT(" &About ... ")       );
 
   // Load the menubar with menus
-  poMenuBar ->Append( poMenuFile,              wxT(" &File ")             );
-  poMenuBar ->Append( poMenuSimu,              wxT(" &Simulate ")         );
-  poMenuBar ->Append( poMenuSets,              wxT(" &Settings ")         );
-  poMenuBar ->Append( poMenuHelp,              wxT(" &Help ")             );
+  poMenuBar ->Append( poMenuFile,              wxT(" &File ")            );
+  poMenuBar ->Append( poMenuSimu,              wxT(" &Simulate ")        );
+  poMenuBar ->Append( poMenuSets,              wxT(" S&ettings ")        );
+  poMenuBar ->Append( poMenuHelp,              wxT(" &Help ")            );
 
   // Check the appropriate simulation engine menu item
   m_poCfg->SetPath( wxT("/Simulator") );
-  if( m_poCfg->Read( wxT("Engine"), wxT("GNUCAP") ) == wxT("NGSPICE") )
+  if( m_poCfg->Read( wxT("Engine"), CLP_GNUCAP ) == CLP_NGSPICE )
        poMenuSets->Check( ID_MNU_NGSPICE, TRUE );
   else poMenuSets->Check( ID_MNU_GNUCAP , TRUE );
 
@@ -247,34 +254,34 @@ void  FrmMain::InitToolBar( void )
   poToolBar->SetToolSeparation( 10 );
 
   poToolBar->AddTool( ID_TBR_OPEN,   wxT(""), *(poPixMap[ 0 ]),
-                      wxT("Open Netlist") );
+                      wxT("Open a netlist file") );
   poToolBar->AddTool( ID_TBR_IMPORT, wxT(""), *(poPixMap[ 1 ]),
-                      wxT("Import Schematic") );
+                      wxT("Import schematic file/s") );
   poToolBar->AddTool( ID_TBR_RELOAD, wxT(""), *(poPixMap[ 2 ]),
-                      wxT("Reload Schem/Netlist") );
+                      wxT("Reload netlist / schematic file/s") );
   poToolBar->AddTool( ID_TBR_CLOSE,  wxT(""), *(poPixMap[ 3 ]),
-                      wxT("Close Schem/Netlist") );
+                      wxT("Close netlist / schematic file/s") );
 
   poToolBar->AddSeparator( );
 
   poToolBar->AddTool( ID_TBR_CREATE, wxT(""), *(poPixMap[ 4 ]),
-                      wxT("Create Simulation") );
+                      wxT("Create a netlist file containing simulation instructions") );
   poToolBar->AddTool( ID_TBR_RUN,    wxT(""), *(poPixMap[ 5 ]),
-                      wxT("Run Simulation") );
+                      wxT("Run the simulation engine process") );
   poToolBar->AddTool( ID_TBR_STOP,   wxT(""), *(poPixMap[ 6 ]),
-                      wxT("Stop Simulation") );
+                      wxT("Stop the simulation engine process") );
 
   poToolBar->AddSeparator( );
 
-  poToolBar->AddTool( ID_TBR_EDIT,   wxT(""), *(poPixMap[ 7 ]),
-                      wxT("Edit Schematic/s") );
-  poToolBar->AddTool( ID_TBR_PLOT,   wxT(""), *(poPixMap[ 8 ]),
-                      wxT("View Results") );
+  poToolBar->AddTool( ID_TBR_SCHEM,  wxT(""), *(poPixMap[ 7 ]),
+                      wxT("Edit / view schematic/s") );
+  poToolBar->AddTool( ID_TBR_VIEWER, wxT(""), *(poPixMap[ 8 ]),
+                      wxT("View results data") );
 
   poToolBar->AddSeparator( );
 
   poToolBar->AddTool( ID_TBR_HELP,   wxT(""), *(poPixMap[ 9 ]),
-                      wxT("User Manual") );
+                      wxT("View the user manual") );
 
   // Realize the toolbar
   poToolBar->Realize( );
@@ -556,6 +563,7 @@ bool  FrmMain::bSimLoad( void )
     const Component & roCpnt = m_poSimultn->m_oaCpnts.Item( sz1 );
     switch( roCpnt.m_eType )     // Only collect two terminal components
     {
+      case eCPNT_SCJN  :         // Super-conductor Junction
       case eCPNT_CAP   :         // Capacitor
       case eCPNT_RES   :         // Resistor
       case eCPNT_ADM   :         // Admittance
@@ -571,14 +579,17 @@ bool  FrmMain::bSimLoad( void )
   for( sz1=0; sz1<m_poSimultn->rosaGetTstCpnts( ).GetCount( ); sz1++ )
     m_oLbxCpnts.SetStringSelection( m_poSimultn->rosaGetTstCpnts().Item(sz1) );
 
-  // Load the raw circuit description into the "NetList" text control
-  m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
-  m_oNbkTxtCtls.bClear( NbkTxtCtls::ePAGE_NETLIST );
-  poTxtCtl = m_oNbkTxtCtls.poGetPage( NbkTxtCtls::ePAGE_NETLIST );
-  poTxtCtl->bClear( );
-  for( sz1=0; sz1<m_oNetLst.m_osaNetLst.GetCount( ); sz1++ )
-    poTxtCtl->bAppendLine( m_oNetLst.m_osaNetLst.Item( sz1 ) );
-  m_oNbkTxtCtls.bSetPosn( 0 );
+  // Load the raw circuit description into the NetList text control
+  if( ! m_oNetLst.m_osaNetLst.IsEmpty( ) )
+  {
+    m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
+    m_oNbkTxtCtls.bClear( NbkTxtCtls::ePAGE_NETLIST );
+    poTxtCtl = m_oNbkTxtCtls.poGetPage( NbkTxtCtls::ePAGE_NETLIST );
+    poTxtCtl->bClear( );
+    for( sz1=0; sz1<m_oNetLst.m_osaNetLst.GetCount( ); sz1++ )
+      poTxtCtl->bAppendLine( m_oNetLst.m_osaNetLst.Item( sz1 ) );
+    m_oNbkTxtCtls.bSetPosn( 0 );
+  }
 
   // Load the analysis notebook with simulation information
   if( ! m_poNbkSimEng->bLoad( *m_poSimultn ) ) return( FALSE );
@@ -706,7 +717,7 @@ void  FrmMain::DlgErrMsg( const wxString & rosTitle, const wxString & rosMsg )
   wxString           os1, os2, os3;
 
   // Tokenize the message into lines
-  ostk1.SetString( rosMsg, wxT("\n\r"), wxTOKEN_STRTOK );
+  ostk1.SetString( rosMsg, wxT(" \n\r"), wxTOKEN_STRTOK );
 
   // Use the first complete sentence as the status bar message
   os1 << wxT(" ERROR :");
@@ -715,25 +726,18 @@ void  FrmMain::DlgErrMsg( const wxString & rosTitle, const wxString & rosMsg )
     // Get the next line
     os2 = ostk1.GetNextToken( ).Strip( wxString::both );
 
-    // Remove the path from any file names
+    // Remove the path from file names
     if( os2.Freq( wxT('/') ) > 1 )
     {
       os3 << os2.AfterLast( wxT('/') ) << wxT(',');
       os2 = os3;
     }
 
-    // Remove duplicate white space characters
-    while( os2.Replace( wxT("  "), wxT(" ") ) ) continue;
+    // Look for the end of the sentence
+    if( os2==wxT('.') || os2==wxT(':') ) break;
 
     // Append the line to the message
     os1 << wxT(' ') << os2;
-
-    // Is this the end of the sentence?
-    if( os1.Last( ) == wxT('.') )
-    {
-      os1.Truncate( os1.Length( )-1 );
-      break;
-    }
   }
 
   // Set the status line message
@@ -819,14 +823,16 @@ bool  FrmMain::bClear( void )
   m_oSimnNgs.bClear( );
 
   // Clear the simulation object and the analysis panels
-  if( ! m_poNbkSimEng->bClear( ) )    bRtn = FALSE;
+  if( m_poNbkSimEng != NULL )
+    if( ! m_poNbkSimEng->bClear( ) )  bRtn = FALSE;
 
   // Clear the text controls
   if( ! m_oNbkTxtCtls.bClear( ) )     bRtn = FALSE;
   m_oNbkTxtCtls.bInitialize( );
 
   // Terminate any simulation process
-  if( ! m_poPrcSimEng->bKill( ) )     bRtn = FALSE;
+  if( m_poPrcSimEng != NULL )
+    if( ! m_poPrcSimEng->bKill( ) )   bRtn = FALSE;
 
   // Terminate any schematic editor process
   if( ! m_oPrcGSchem.bKill( ) )       bRtn = FALSE;
@@ -852,20 +858,14 @@ bool  FrmMain::bClear( void )
 
 void  FrmMain::OnOpen( wxCommandEvent & roEvtCmd )
 {
-  wxString  os1;
+  // Attempt to get a netlist file name from the user
+  if( ! m_oFileTsks.bDlgOpen( ) ) return;
 
-  // Get a netlist file name from the user and attempt to open it
-  if( m_oFileTsks.bOpen( ) )
-  {
-    // Attempt to load the simulation information
-    if( bSimLoad( ) )
-         os1 = wxT(" Netlist file opened successfully");
-    else os1 = wxT(" Error/s encountered opening a netlist file");
+  // Attempt to open and read the netlist file
+  if( ! m_oFileTsks.bOpen( ) )    return;
 
-    // Set the status text and initialize the process log files
-    SetStatusText( os1, 1 );
-    InitLogFiles( );
-  }
+  bSimLoad( );      // Load the simulation information
+  InitLogFiles( );  // Initialize the process log files
 }
 
 //*****************************************************************************
@@ -877,20 +877,14 @@ void  FrmMain::OnOpen( wxCommandEvent & roEvtCmd )
 
 void  FrmMain::OnImport( wxCommandEvent & roEvtCmd )
 {
-  wxString  os1;
+  // Attempt to get the schematic file name/s from the user
+  if( ! m_oFileTsks.bDlgImport( ) ) return;
 
-  // Get schematic file name/s from the user and attempt to import them
-  if( m_oFileTsks.bImport( ) )
-  {
-    // Attempt to load the simulation information
-    if( bSimLoad( ) )
-         os1 = wxT(" Schematic file/s imported successfully");
-    else os1 = wxT(" Error/s encountered importing schematic file/s");
+  // Attempt to import the schematic file/s and read the netlist file
+  if( ! m_oFileTsks.bImport( ) )    return;
 
-    // Set the status text and initialize the process log files
-    SetStatusText( os1, 1 );
-    InitLogFiles( );
-  }
+  bSimLoad( );      // Load the simulation information
+  InitLogFiles( );  // Initialize the process log files
 }
 
 //*****************************************************************************
@@ -901,19 +895,8 @@ void  FrmMain::OnImport( wxCommandEvent & roEvtCmd )
 
 void  FrmMain::OnReload( wxCommandEvent & roEvtCmd )
 {
-  wxString  os1;
-
-  // Reload schematic file/s or a netlist file into the Simulation object
-  if( m_oFileTsks.bReload( ) )
-  {
-    // Attempt to reload the simulation information
-    if( bSimReload( ) )
-         os1 = wxT(" Netlist file reloaded successfully");
-    else os1 = wxT(" Error/s encountered reloading the netlist file");
-
-    // Set the status text
-    SetStatusText( os1, 1 );
-  }
+  m_oFileTsks.bReload( );  // Reload schematic file/s or the netlist file
+  bSimReload( );           // Reload the simulation information
 }
 
 //*****************************************************************************
@@ -1116,12 +1099,12 @@ void  FrmMain::OnSimStop( wxCommandEvent & roEvtCmd )
 }
 
 //*****************************************************************************
-// Edit the schematic file.
+// Edit / view the schematic file.
 //
 // Argument List :
 //   roEvtCmd - The event to be processed
 
-void  FrmMain::OnEditSchem( wxCommandEvent & roEvtCmd )
+void  FrmMain::OnSchematic( wxCommandEvent & roEvtCmd )
 {
   wxString  os1;
 
@@ -1211,7 +1194,7 @@ void  FrmMain::OnViewData( wxCommandEvent & roEvtCmd )
 
   // Execute the waveform viewer process
   m_poCfg->SetPath( wxT("/Viewer") );
-  if( m_poCfg->Read( wxT("Name") ).Upper( ) == CLP_GWAVE )
+  if( m_poCfg->Read( wxT("Name") ) == CLP_GWAVE )
   {
     if( ! m_oPrcGWave.bExec( ) )
       DlgErrMsg( os1, m_oPrcGWave.rosGetErrMsg( ) );
@@ -1326,7 +1309,7 @@ void  FrmMain::OnPrefs( wxCommandEvent & roEvtCmd )
     SetStatusText( os1, 3 );
 
     // Set the text control maximum lines
-    m_oNbkTxtCtls.bSetLinesMax( oDlgPrefs.iGetMaxLines( ) );
+    m_oNbkTxtCtls.bSetLinesMax( oDlgPrefs.iGetNbkMaxLines( ) );
   }
 }
 
@@ -1359,7 +1342,7 @@ void  FrmMain::OnAbout( wxCommandEvent & roEvtCmd )
 // Argument List :
 //   roEvtCmd - The event to be processed
 
-void  FrmMain::OnTbrEnter( wxCommandEvent & roEvtCmd )
+void  FrmMain::OnToolEnter( wxCommandEvent & roEvtCmd )
 {
   if( roEvtCmd.GetSelection( ) == ID_TBR_STOP )
   {
@@ -1402,7 +1385,7 @@ void  FrmMain::OnSysExit( wxCloseEvent & roEvtClose )
 
   // Record the simulation engine currently selected
   m_poCfg->SetPath( wxT("/Simulator") );
-  os1 = m_poPrcSimEng->eGetSimEng( ) == eSIMR_GNUCAP ? CLP_GNUCAP : CLP_NGSPICE;
+  os1 = m_poPrcSimEng->eGetSimEng( )==eSIMR_GNUCAP ? CLP_GNUCAP : CLP_NGSPICE;
   m_poCfg->Write( wxT("Engine"), os1 );
 
   // Record the analysis type last used
