@@ -216,8 +216,8 @@ bool  NbkTxtCtls::bSetPosn( long liPosn )
   if( poTxtCtl == NULL ) return( FALSE );
 
   // Set the position
-  poTxtCtl->SetInsertionPoint( liPosn );
-//  poTxtCtl->ShowPosition( liPosn ); ??? 18/06/2005
+  if( liPosn >= 0 ) poTxtCtl->SetInsertionPoint( liPosn );
+  else              poTxtCtl->SetInsertionPointEnd( );
 
   return( TRUE );
 }
