@@ -2,7 +2,7 @@
 //                                Component.cpp                               *
 //                               ---------------                              *
 // Started     : 14/05/2004                                                   *
-// Last Update : 12/10/2009                                                   *
+// Last Update : 15/04/2010                                                   *
 // Copyright   : (C) 2004 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -273,11 +273,12 @@ bool  Component::bSetNodes( const wxString & rosNodes )
 
   // Tokenize the name string
   ostk1.SetString( rosNodes, wxT(" \t\r\n,") );
-  if( ostk1.CountTokens( ) <=0 )          return( FALSE );
+  if( ostk1.CountTokens( ) <=0 )         return( FALSE );
 
   // Determine how many nodes to look for based on the component type
   switch( m_eType )
   {
+    case eCPNT_SCJN   :
     case eCPNT_CAP    :
     case eCPNT_DIODE  :
     case eCPNT_VCVS   :
@@ -289,19 +290,21 @@ bool  Component::bSetNodes( const wxString & rosNodes )
     case eCPNT_IND    :
     case eCPNT_RES    :
     case eCPNT_IVS    :
-    case eCPNT_ADM    : szNodeCnt = 2;       break;
+    case eCPNT_ADM    : szNodeCnt = 2;                         break;
 
     case eCPNT_JFET   :
     case eCPNT_MOS    :
     case eCPNT_BJT    :
     case eCPNT_VCSW   :
-    case eCPNT_CCSW   : szNodeCnt = 3;       break;
+    case eCPNT_CCSW   : szNodeCnt = 3;                        break;
 
-    case eCPNT_TLINE  :
-    case eCPNT_LOGIC  :
-    case eCPNT_SUBCKT :
+    case eCPNT_TLINE  : szNodeCnt = 3;                        break;
 
-    default           : szNodeCnt = 0;       break;
+    case eCPNT_LOGIC  : szNodeCnt = ostk1.CountTokens( ) - 2; break;
+
+    case eCPNT_SUBCKT : szNodeCnt = ostk1.CountTokens( ) - 1; break;
+
+    default           : szNodeCnt = 0;                        break;
   }
   if( szNodeCnt > ostk1.CountTokens( ) ) return( FALSE );
 
@@ -429,6 +432,7 @@ eCpntType  Component::eGetCpntType( const wxString & rosName )
   // Determine the component type from the first character of the name
   switch( toupper( rosName.GetChar( 0 ) ) )
   {
+    case wxT('B') : return( eCPNT_SCJN   );
     case wxT('C') : return( eCPNT_CAP    );
     case wxT('D') : return( eCPNT_DIODE  );
     case wxT('E') : return( eCPNT_VCVS   );
@@ -449,6 +453,7 @@ eCpntType  Component::eGetCpntType( const wxString & rosName )
     case wxT('W') : return( eCPNT_CCSW   );
     case wxT('X') : return( eCPNT_SUBCKT );
     case wxT('Y') : return( eCPNT_ADM    );
+
     default       : return( eCPNT_NONE   );
   }
 }
@@ -468,6 +473,7 @@ eUnitsType  Component::eGetUnitsType( const wxString & rosName )
   // Determine the units type from the first character of the name
   switch( toupper( rosName.GetChar( 0 ) ) )
   {
+    case wxT('B') : return( eUNITS_SCLR );
     case wxT('C') : return( eUNITS_CAP  );
     case wxT('D') : return( eUNITS_NONE );
     case wxT('E') : return( eUNITS_SCLR );
@@ -488,6 +494,7 @@ eUnitsType  Component::eGetUnitsType( const wxString & rosName )
     case wxT('W') : return( eUNITS_NONE );
     case wxT('X') : return( eUNITS_NONE );
     case wxT('Y') : return( eUNITS_RES  );
+
     default       : return( eUNITS_NONE );
   }
 }
@@ -582,6 +589,7 @@ void  Component::Print( const wxString & rosPrefix )
   cout << osPrefix  .mb_str( ) << "m_eType          : ";
   switch( m_eType )
   {
+    case eCPNT_SCJN   : cout << "eCPNT_SCJN";   break;
     case eCPNT_ADM    : cout << "eCPNT_ADM";    break;
     case eCPNT_BJT    : cout << "eCPNT_BJT";    break;
     case eCPNT_CAP    : cout << "eCPNT_CAP";    break;
@@ -603,6 +611,7 @@ void  Component::Print( const wxString & rosPrefix )
     case eCPNT_VCSW   : cout << "eCPNT_VCSW";   break;
     case eCPNT_VCVS   : cout << "eCPNT_VCVS";   break;
     case eCPNT_NONE   : cout << "eCPNT_NONE";   break;
+
     default           : cout << "Invalid";
   }
   cout << '\n';
@@ -643,6 +652,7 @@ void  Component::Print( const wxString & rosPrefix )
     case eUNITS_TEMP  : cout << "eUNITS_TEMP";  break;
     case eUNITS_SCLR  : cout << "eUNITS_SCLR";  break;
     case eUNITS_NONE  : cout << "eUNITS_NONE";  break;
+
     default           : cout << "Invalid";      break;
   }
   cout << '\n';
@@ -674,7 +684,7 @@ int  main( int argc, char * argv[ ] )
   wxString  os1;
 
   // Validate the argument count passed to the application
-  if( argc > 2 )           { Usage( argv[ 0 ] ); exit( EXIT_FAILURE ); }
+  if( argc > 2 )                    { Usage( argv[0] ); exit( EXIT_FAILURE ); }
 
   // Process the command line arguments
   os1 = wxConvLibc.cMB2WC( argv[ 1 ] );
@@ -682,8 +692,8 @@ int  main( int argc, char * argv[ ] )
   {
     if( os1.at( 0 ) == wxT('-') )
     {
-      if( os1.at( 1 ) == wxT('h') ) { Usage( argv[ 0 ] ); exit( EXIT_SUCCESS ); }
-      else                          { Usage( argv[ 0 ] ); exit( EXIT_FAILURE ); }
+      if( os1.at( 1 ) == wxT('h') ) { Usage( argv[0] ); exit( EXIT_SUCCESS ); }
+      else                          { Usage( argv[0] ); exit( EXIT_FAILURE ); }
     }
   }
 
