@@ -2,7 +2,7 @@
 //                                NetList.cpp                                 *
 //                               -------------                                *
 // Started     : 01/09/2003                                                   *
-// Last Update : 12/10/2009                                                   *
+// Last Update : 15/04/2010                                                   *
 // Copyright   : (C) 2003 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -477,7 +477,7 @@ bool  NetList::bValidate( void )
 }
 
 //*****************************************************************************
-// Load (or reload) the circuit from file.
+// Load (or reload) a circuit description from file.
 //
 // Argument List :
 //   rosFName - The name of the file to be loaded
@@ -514,7 +514,7 @@ bool  NetList::bLoadFile( const wxString & rosFName )
   oFileCct.Close( ); // Close the file
 
   // Attempt to extract the circuit description from file
-  if( ! bExtract( ) )             { m_osaNetLst.Empty( ); return( FALSE ); }
+  if( ! bExtract( ) )                                     return( FALSE );
 
   return( TRUE );
 }
@@ -804,8 +804,7 @@ void  NetList::Print( const wxString & rosPrefix )
   {
     for( sz1=0; sz1<m_osaNetLst.GetCount( ); sz1++ )
     {
-      if( sz1 > 0 )
-        cout << rosPrefix.mb_str( ) << "                   ";
+      if( sz1 > 0 ) cout << rosPrefix.mb_str( ) << "                   ";
       cout << m_osaNetLst.Item( sz1 ).mb_str( ) << '\n';
     }
   }
@@ -816,8 +815,7 @@ void  NetList::Print( const wxString & rosPrefix )
   {
     for( sz1=0; sz1<m_osaTitle.GetCount( ); sz1++ )
     {
-      if( sz1 > 0 )
-        cout << rosPrefix.mb_str( ) << "                   ";
+      if( sz1 > 0 ) cout << rosPrefix.mb_str( ) << "                   ";
       cout << m_osaTitle.Item( sz1 ).mb_str( ) << '\n';
     }
   }
@@ -828,8 +826,7 @@ void  NetList::Print( const wxString & rosPrefix )
   {
     for( sz1=0; sz1<m_osaIncludes.GetCount( ); sz1++ )
     {
-      if( sz1 > 0 )
-        cout << rosPrefix.mb_str( ) << "                   ";
+      if( sz1 > 0 ) cout << rosPrefix.mb_str( ) << "                   ";
       cout << m_osaIncludes.Item( sz1 ).mb_str( ) << '\n';
     }
   }
@@ -840,8 +837,7 @@ void  NetList::Print( const wxString & rosPrefix )
   {
     for( sz1=0; sz1<m_oaCpnts.GetCount( ); sz1++ )
     {
-      if( sz1 > 0 )
-        cout << rosPrefix.mb_str( ) << "                   ";
+      if( sz1 > 0 ) cout << rosPrefix.mb_str( ) << "                   ";
       cout << m_oaCpnts.Item( sz1 ).rosGetString( ).mb_str( ) << '\n';
     }
   }
@@ -852,8 +848,7 @@ void  NetList::Print( const wxString & rosPrefix )
   {
     for( sz1=0; sz1<m_osaModels.GetCount( ); sz1++ )
     {
-      if( sz1 > 0 )
-        cout << rosPrefix.mb_str( ) << "                   ";
+      if( sz1 > 0 ) cout << rosPrefix.mb_str( ) << "                   ";
       cout << m_osaModels.Item( sz1 ).mb_str( ) << '\n';
     }
   }
@@ -864,8 +859,7 @@ void  NetList::Print( const wxString & rosPrefix )
   {
     for( sz1=0; sz1<m_osaSubCcts.GetCount( ); sz1++ )
     {
-      if( sz1 > 0 )
-        cout << rosPrefix.mb_str( ) << "                   ";
+      if( sz1 > 0 ) cout << rosPrefix.mb_str( ) << "                   ";
       cout << m_osaSubCcts.Item( sz1 ).mb_str( ) << '\n';
     }
   }
