@@ -2,7 +2,7 @@
 //                              CmdNgSpiceDC.cpp                              *
 //                             ------------------                             *
 // Started     : 21/08/2007                                                   *
-// Last Update : 14/10/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2007 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -241,7 +241,7 @@ void  CmdNgSpiceDC::Print( const wxString & rosPrefix )
 //                                                                            *
 //*****************************************************************************
 
-#ifdef TEST_UTIL
+#ifdef TEST_CMDNGSDC
 
 // System include files
 
@@ -315,6 +315,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_UTIL
+#endif // TEST_CMDNGSDC
 
 //*****************************************************************************
