@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the NG-Spice      *
 //               DC command. It inherits from the class CmdBase.              *
 // Started     : 23/08/2006                                                   *
-// Last Update : 13/05/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -18,8 +18,8 @@
 //                                                                            *
 //*****************************************************************************
 
-#ifndef CMDNGSPICEDC_HPP
-#define CMDNGSPICEDC_HPP
+#ifndef CMDNGSDC_HPP
+#define CMDNGSDC_HPP
 
 // System Includes
 
@@ -76,4 +76,4 @@ struct CmdNgSpiceDC : public CmdBase
 
 //*****************************************************************************
 
-#endif // CMDNGSPICEDC_HPP
+#endif // CMDNGSDC_HPP
