@@ -2,7 +2,7 @@
 //                              DlgNgsCfgOPT.cpp                              *
 //                             ------------------                             *
 //  Started     : 03/03/2006                                                  *
-//  Last Update : 10/06/2009                                                  *
+//  Last Update : 23/02/2010                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -587,7 +587,10 @@ void  DlgNgsCfgOPT::OnBtnOk( wxCommandEvent & roEvtCmd )
 
 void  DlgNgsCfgOPT::OnBtnDefaults( wxCommandEvent & roEvtCmd )
 {
-  bClear( );
+  CmdNgSpiceOPT  oCmdOPT;
+
+  oCmdOPT.bClear( );
+  SetValues( oCmdOPT );
 }
 
 //*****************************************************************************
