@@ -2,7 +2,7 @@
 //                             PnlNgSpiceDC.cpp                               *
 //                            ------------------                              *
 // Started     : 08/05/2004                                                   *
-// Last Update : 21/08/2009                                                   *
+// Last Update : 13/04/2010                                                   *
 // Copyright   : (C) 2004 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -319,6 +319,9 @@ void  PnlNgSpiceDC::OnSwpType( wxCommandEvent & roEvtCmd )
 void  PnlNgSpiceDC::OnSrcName( wxCommandEvent & roEvtCmd )
 {
   InitSwpUnits( );
+
+  // Permit the base class to process this event as well
+  roEvtCmd.Skip( );
 }
 
 //*****************************************************************************
