@@ -5,7 +5,7 @@
 //               provides a GUI for a user to configure a DC Analysis for     *
 //               NG-Spice electronic circuit simulator.                       *
 // Started     : 08/05/2004                                                   *
-// Last Update : 21/08/2009                                                   *
+// Last Update : 16/04/2010                                                   *
 // Copyright   : (C) 2004 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -55,10 +55,10 @@ class PnlNgSpiceDC : public PnlAnaBase
   private :
 
     // Sweep type
-    wxRadioBox    m_oRbxSwpType;
+    wxRadioBox  m_oRbxSwpType;
 
     // Sweep source
-    wxStaticText  m_oLblSrcCpnt;
+    wxLabel     m_oLblSrcCpnt;
 
     void  Create( void );
     void  InitSwpType( void );
