@@ -2,7 +2,7 @@
 //                                  PrcGWave.cpp                              *
 //                                 --------------                             *
 //  Started     : 29/03/2004                                                  *
-//  Last Update : 29/02/2008                                                  *
+//  Last Update : 12/03/2010                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -246,7 +246,7 @@ bool  PrcGWave::bExec( void )
   if( ! bFormatFile( ) )                            return( FALSE );
 
   // Execute the process
-  if( ! PrcBase::bExec( ) )                         return( FALSE );
+  if( ! PrcBase::bExecAsync( ) )                    return( FALSE );
 
   return( TRUE );
 }
