@@ -1,10 +1,10 @@
 //*****************************************************************************
-//                               PrcGnucap.hpp                                *
+//                               PrcGnuCap.hpp                                *
 //                              ---------------                               *
 //  Description : This class provides the interface to the GNU-Cap electronic *
 //                circuit simulator.                                          *
 //  Started     : 01/09/2003                                                  *
-//  Last Update : 07/01/2008                                                  *
+//  Last Update : 14/07/2009                                                  *
 //  Copyright   : (C) 2003 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -31,7 +31,15 @@
 
 // Application Includes
 
+#include "TypeDefs.hpp"
 #include "base/PrcSimrBase.hpp"
+#include "netlist/SimnGnuCap.hpp"
+#include "gnucap/commands/CmdGnuCapOP.hpp"
+#include "gnucap/commands/CmdGnuCapDC.hpp"
+#include "gnucap/commands/CmdGnuCapAC.hpp"
+#include "gnucap/commands/CmdGnuCapTR.hpp"
+#include "gnucap/commands/CmdGnuCapFO.hpp"
+#include "gnucap/commands/CmdGnuCapPR.hpp"
 #include "utility/ConvertType.hpp"
 
 // Local Constant Declarations
@@ -47,31 +55,10 @@ class PrcGnuCap : public PrcSimrBase
     // The label for the X axis variable (sometimes missing in GNU-Cap)
     wxString  m_osInput;
 
-    // Functions to parse simulator commands
-    bool  bParseCmdGEN( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdOP ( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdDC ( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdAC ( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdTR ( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdFO ( wxString & rosCmd, Simulation & roSim );
-    bool  bParseCmdPR ( wxString & rosCmd, Simulation & roSim );
-
-    // Functions to create the simulator commands
-    void  MakeCmdOP( Simulation & roSim );
-    void  MakeCmdDC( Simulation & roSim );
-    void  MakeCmdAC( Simulation & roSim );
-    void  MakeCmdTR( Simulation & roSim );
-    void  MakeCmdFO( Simulation & roSim );
-    bool  bMakeCmds( Simulation & roSim );
-
-    // Create arguments for the PRINT command
-    wxString & rosMakeArgsPR( Simulation & roSim, wxString & rosPrefix );
-
     // Functions to check / format the circuit description lines
-    bool  bFmtCpnts( wxArrayString & roasCpnts );
+//    bool  bFmtCpnts( ArrayComponent & roaCpnts ); ??? 17/08/2009
 
     // Format the results file
-    bool  bFmtResults  ( void );
     bool  bFmtGeneric  ( void );
     bool  bFmtResultsFO( void );
     bool  bFmtColumnHdr( void );
@@ -82,10 +69,11 @@ class PrcGnuCap : public PrcSimrBase
     PrcGnuCap( void );
    ~PrcGnuCap( );
 
-    // Parse the simulation commands
-    virtual  bool  bParseSim( Simulation & roSim );
-    // Make the simulation commands
-    virtual  bool  bMakeSim( Simulation & roSim );
+    // Create the process argument list
+    virtual  bool  bMakeArgLst( SimnBase & roSimn );
+
+    // Format the results file
+    virtual  bool  bFmtResults( void );
 };
 
 //*****************************************************************************
