@@ -2,7 +2,7 @@
 //                                ConvertType.hpp                             *
 //                               -----------------                            *
 //  Started     : 21/09/2004                                                  *
-//  Last Update : 27/02/2009                                                  *
+//  Last Update : 19/02/2010                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -60,6 +60,7 @@ bool  ConvertType::bSetFltRes( int iFltRes )
 
 //*****************************************************************************
 // Extract the numeric part of a string.
+// Eg. 10.0E-2uVolt becomes 10.0E-8 and 0.0E-2uF becomes 0.0E-8.
 //
 // Argument List :
 //   rosNum - The string containing a numeric value
@@ -262,9 +263,9 @@ bool  ConvertType::bDFltToStrEng( double dfNum, wxString & rosNum )
   if( ! bParseFlt( dfNum, &fMan, &iExp ) ) return( FALSE );
 
   // Round the mantissa based on the desired resolution
-  fMan *= pow10f( (float) m_iFltRes );
+  fMan *= pow( 10.0, (float) m_iFltRes );
   fMan = roundf( fMan );
-  fMan /= pow10f( (float) m_iFltRes );
+  fMan /= pow( 10.0, (float) m_iFltRes );
 
   // Scale the mantissa so that the exponent is a multiple of 3
   while( iExp % 3 )
@@ -273,7 +274,7 @@ bool  ConvertType::bDFltToStrEng( double dfNum, wxString & rosNum )
     fMan *= 10.0;
   }
 
-  // Determine the appropriate alpha scaling factor
+  // Determine the appropriate scaling factor to be appended as units
   switch( iExp )
   {
     case  12 : osFmt << wxT("Tera");  break;
@@ -465,21 +466,31 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  ConvertType Class Test Utility"
-       << "\n    Version 1.02 (27/02/2009)\n\n";
+       << "\n    Version 1.05 (19/02/2010)\n\n";
 
-  cout << "ConvertType::bStrToLong( )    : ";
+  cout << "ConvertType::rosGetNum    ( ) : ";
+  osNum = wxT("-10.0E-2uF");
+  os1 = ConvertType::rosGetNum( osNum );
+  cout << osNum.mb_str( ) << " -> " << os1.mb_str( ) << "\n";
+
+  cout << "ConvertType::rosGetNum    ( ) : ";
+  osNum = wxT("0.0E2uVolt");
+  os1 = ConvertType::rosGetNum( osNum );
+  cout << osNum.mb_str( ) << " -> " << os1.mb_str( ) << "\n";
+
+  cout << "ConvertType::bStrToLong   ( ) : ";
   osNum = wxT("123.5V");
   if( ConvertType::bStrToLong( osNum, &liNum ) )         cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << osNum.mb_str( ) << " -> " << liNum << ")\n";
 
-  cout << "ConvertType::bStrToDFlt( )    : ";
+  cout << "ConvertType::bStrToDFlt   ( ) : ";
   osNum = wxT("123.4V");
   if( ConvertType::bStrToDFlt( osNum, &dfNum ) )         cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << osNum.mb_str( ) << " -> " << dfNum << ")\n";
 
-  cout << "ConvertType::bDFltToStr( )    : ";
+  cout << "ConvertType::bDFltToStr   ( ) : ";
   dfNum = 1.23E+04;
   if( ConvertType::bDFltToStr( dfNum, osNum ) )          cout << "Success";
   else                                                   cout << "Failure";
@@ -491,37 +502,37 @@ int  main( int argc, char * argv[ ] )
   else                                                   cout << "Failure";
   cout << " (" << dfNum << " -> " << osNum.mb_str( ) << ")\n";
 
-  cout << "ConvertType::bParseDFlt( )    : ";
+  cout << "ConvertType::bParseDFlt   ( ) : ";
   dfNum = 12.3E-04;
   if( ConvertType::bParseDFlt( dfNum, &fMan, &iExp ) )   cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << dfNum << " -> " << fMan << "E" << iExp << ")\n";
 
-  cout << "ConvertType::bStrToInt( )     : ";
+  cout << "ConvertType::bStrToInt    ( ) : ";
   osNum = wxT("123.45E-5");
   if( ConvertType::bStrToInt( osNum, &iNum ) )           cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << osNum.mb_str( ) << " -> " << iNum << ")\n";
 
-  cout << "ConvertType::bStrToFlt( )     : ";
+  cout << "ConvertType::bStrToFlt    ( ) : ";
   osNum = wxT("123.45E-5");
   if( ConvertType::bStrToFlt( osNum, &fNum ) )           cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << osNum.mb_str( ) << " -> " << fNum << ")\n";
 
-  cout << "ConvertType::bFltToStr( )     : ";
+  cout << "ConvertType::bFltToStr    ( ) : ";
   fNum = 1.23E+04;
   if( ConvertType::bFltToStr( fNum, osNum ) )            cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << fNum << " -> " << osNum.mb_str( ) << ")\n";
 
-  cout << "ConvertType::bFltToStrEng( )  : ";
+  cout << "ConvertType::bFltToStrEng ( ) : ";
   fNum = 1.23E+04;
   if( ConvertType::bFltToStrEng( fNum, osNum ) )         cout << "Success";
   else                                                   cout << "Failure";
   cout << " (" << fNum << " -> " << osNum.mb_str( ) << ")\n";
 
-  cout << "ConvertType::bParseFlt( )     : ";
+  cout << "ConvertType::bParseFlt    ( ) : ";
   fNum = 12.3E-04;
   if( ConvertType::bParseFlt( fNum, &fMan, &iExp ) )     cout << "Success";
   else                                                   cout << "Failure";
