@@ -2,7 +2,7 @@
 //                                 PnlValue.cpp                               *
 //                                --------------                              *
 //  Started     : 14/09/2004                                                  *
-//  Last Update : 21/01/2009                                                  *
+//  Last Update : 22/02/2010                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -48,10 +48,10 @@ PnlValue::~PnlValue( )
 // choice control.
 // Note: This conversion will only be done if the units are of temperature.
 //
-// Argument List:
+// Argument List :
 //   pfValue - The value to be converted
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -63,9 +63,9 @@ bool  PnlValue::bTempToDegC( float * pfValue )
 
   switch( m_oChoUnits.GetSelection( ) )
   {
-    case 0:                                       break; // Celcius
-    case 1: *pfValue = (*pfValue + 32.0) / 2.44 ; break; // Fahrenheit
-    case 2: *pfValue -= 273.15;                   break; // Kelvin
+    case 0 :                                       break; // Celcius
+    case 1 : *pfValue = (*pfValue + 32.0) / 2.44 ; break; // Fahrenheit
+    case 2 : *pfValue -= 273.15;                   break; // Kelvin
     default: return( FALSE );
   }
 
@@ -77,10 +77,10 @@ bool  PnlValue::bTempToDegC( float * pfValue )
 // choice control.
 // Note: This conversion will only be done if the units are of phase.
 //
-// Argument List:
+// Argument List :
 //   pfValue - The value to be converted
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -92,9 +92,9 @@ bool  PnlValue::bPhaseToDeg( float * pfValue )
 
   switch( m_oChoUnits.GetSelection( ) )
   {
-    case 0:                     break; // Degree
-    case 1: *pfValue /= 6.2832; break; // Radian
-    case 2: *pfValue *= 0.9;    break; // Grad
+    case 0 :                     break; // Degree
+    case 1 : *pfValue /= 6.2832; break; // Radian
+    case 2 : *pfValue *= 0.9;    break; // Grad
     default: return( FALSE );
   }
 
@@ -147,14 +147,14 @@ oFlags.Border( wxTOP, 7 );            // ??? 26/05/2007
 //*****************************************************************************
 // Create an instance of this object.
 //
-// Argument List:
+// Argument List :
 //   poWin  - The parent window
 //   oWinID - The window identifier
 //   iWidth - The width of the name label in pixels
 //   roPosn - The position
 //   bUnits - Flag indicating if units should be accommodated
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -196,10 +196,9 @@ bool  PnlValue::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth,
   // Layout the display objects
   DoLayout( );
 
-
 // (15/10/2008) I suspect that the following just fixes a bug in wxWidgets, the
 // back-ground of the parent window isn't inherited by it's children
-this->SetBackgroundColour( poWin->GetBackgroundColour( ) ); // ???
+this->SetBackgroundColour( poWin->GetBackgroundColour( ) ); // ??? 15/10/2008
 
   return( bRtn );
 }
@@ -207,7 +206,7 @@ this->SetBackgroundColour( poWin->GetBackgroundColour( ) ); // ???
 //*****************************************************************************
 // Clear the spin and choice values.
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -224,10 +223,10 @@ bool  PnlValue::bClear( void )
 //*****************************************************************************
 // Set the name label.
 //
-// Argument List:
+// Argument List :
 //   rosName - The name of the variable
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -245,10 +244,10 @@ bool  PnlValue::bSetName( const wxString & rosName )
 //*****************************************************************************
 // Set the variable type for the spin control to display.
 //
-// Argument List:
+// Argument List :
 //   eVType - The variable type
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -262,11 +261,11 @@ bool  PnlValue::bSetVarType( SpinCtrl::eVarType eVType )
 //*****************************************************************************
 // Set the spin control range.
 //
-// Argument List:
+// Argument List :
 //   fMinValue - The spin control minimum value
 //   fMaxValue - The spin control maximum value
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -286,11 +285,11 @@ bool  PnlValue::bSetRange( float fMinValue, float fMaxValue )
 // step size means that the spin control is incremented by an amount dependent
 // on it's current value.
 //
-// Argument List:
+// Argument List :
 //   fMinIncSz - The minimum spin control increment size
 //   fMaxIncSz - The maximum spin control increment size
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -304,14 +303,14 @@ bool  PnlValue::bSetIncSz( float fMinIncSz, float fMaxIncSz )
 //*****************************************************************************
 // Set the spin control parameters.
 //
-// Argument List:
+// Argument List :
 //   fDefValue - The spin control initial value
 //   fMinValue - The spin control minimum value
 //   fMaxValue - The spin control maximum value
 //   fMinIncSz - The spin control minimum increment size
 //   fMaxIncSz - The spin control maximum increment size
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -331,11 +330,11 @@ bool  PnlValue::bSetParms( float fDefValue, float fMinValue, float fMaxValue,
 //*****************************************************************************
 // Set the spin control value as an integer.
 //
-// Argument List:
+// Argument List :
 //   liValue  - The long integer value
 //   bNoUnits - Flag indicating if the units should be updated
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -378,11 +377,11 @@ bool  PnlValue::bSetValue( long liValue, bool bNoUnits )
 //*****************************************************************************
 // Set the spin control value as a float.
 //
-// Argument List:
+// Argument List :
 //   dfValue  - The double float value
 //   bNoUnits - Flag indicating if the units should be updated
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -419,24 +418,37 @@ bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
 }
 
 //*****************************************************************************
-// Set the spin control value as a string
+// Set the spin control value as a string.
 //
-// Argument List:
+// Argument List :
 //   rosValue - The string value
 //   bNoUnits - Flag indicating if the units should be updated
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
 bool  PnlValue::bSetValue( const wxString & rosValue, bool bNoUnits )
 {
-  double  df1;
+  wxString  os1;
+  double    df1;
+  float     f1;
+  int       i1;
 
-  if( ! bIsCreated( ) )                             return( FALSE );
+  if( ! bIsCreated( ) )                              return( FALSE );
 
-  if( ! ConvertType::bStrToDFlt( rosValue, &df1 ) ) return( FALSE );
-  if( ! bSetValue( df1, bNoUnits ) )                return( FALSE );
+  // Set the value
+  if( ! ConvertType::bStrToDFlt( rosValue, &df1 ) )  return( FALSE );
+  if( ! bSetValue( df1, bNoUnits ) )                 return( FALSE );
+
+  if( df1==0.0 && !bNoUnits )
+  { // If the value is attempt to set the units
+    os1 = rosValue;
+    os1.at( 0 ) = '1';
+    if( ! ConvertType::bStrToDFlt( os1, &df1 ) )     return( FALSE );
+    if( ! ConvertType::bParseDFlt( df1, &f1, &i1 ) ) return( FALSE );
+    if( ! m_oChoUnits.bSetUnits( i1 ) )              return( FALSE );
+  }
 
   return( TRUE );
 }
@@ -444,14 +456,14 @@ bool  PnlValue::bSetValue( const wxString & rosValue, bool bNoUnits )
 //*****************************************************************************
 // Set the type of units to be displayed in the choice control.
 //
-// Argument List:
+// Argument List :
 //   eUType  - The units specifier
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  PnlValue::bSetUnitsType( eUnitsType  eUType )
+bool  PnlValue::bSetUnitsType( eUnitsType eUType )
 {
   bool  bRtn;
 
@@ -465,34 +477,44 @@ bool  PnlValue::bSetUnitsType( eUnitsType  eUType )
     case eUNITS_CAP   :  // Capacitance
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_IND   :  // Inductance
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_RES   :  // Resistance
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_VOLT  :  // Voltage
       bRtn = m_oSpnValue.bSetParms( 100.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_CURR  :  // Current
       bRtn = m_oSpnValue.bSetParms( 100.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_TIME  :  // Time
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_FREQ  :  // Frequency
       bRtn = m_oSpnValue.bSetParms( 100.0,     0.0, 1000.0, 1.0, 100.0 );
       break;
+
     case eUNITS_PHASE :  // Phase
       bRtn = m_oSpnValue.bSetParms(   0.0,     0.0,  360.0, 5.0 );
       break;
+
     case eUNITS_TEMP  :  // Temperature
       bRtn = m_oSpnValue.bSetParms(  27.0,  -100.0,  200.0, 1.0,   5.0 );
       break;
+
     case eUNITS_SCLR  :  // Scalar
       bRtn = m_oSpnValue.bSetParms(   1.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
-    default:                       // Default
+
+    default           :  // Default
       bRtn = m_oSpnValue.bSetParms( 100.0, -1000.0, 1000.0, 1.0, 100.0 );
       break;
   }
@@ -503,10 +525,10 @@ bool  PnlValue::bSetUnitsType( eUnitsType  eUType )
 //*****************************************************************************
 // Set the units to be displayed in the choice control or static label.
 //
-// Argument List:
+// Argument List :
 //   rosUnits - The units to be displayed
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -526,10 +548,10 @@ bool  PnlValue::bSetUnits( const wxString & rosUnits )
 //*****************************************************************************
 // Show or hide the units choice control.
 //
-// Argument List:
+// Argument List :
 //   bEnable - The new state for the units choice control
 //
-// Return Values:
+// Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
@@ -554,7 +576,7 @@ bool  PnlValue::bShowUnits( bool bEnable )
 //*****************************************************************************
 // Get the variable name.
 //
-// Return Values:
+// Return Values :
 //   Success - The variable name as a string
 //   Failure - An empty string
 
@@ -574,7 +596,7 @@ const wxString & PnlValue::rosGetName( void )
 //*****************************************************************************
 // Get the spin control value including units as an integer.
 //
-// Return Values:
+// Return Values :
 //   Success - The value as a long integer
 //   Failure - LONG_MIN
 
@@ -607,7 +629,7 @@ long  PnlValue::liGetValue( void )
 //*****************************************************************************
 // Get the spin control value including units as a float.
 //
-// Return Values:
+// Return Values :
 //   Success - The value as a double precision float
 //   Failure - -DBL_MAX
 
@@ -634,7 +656,7 @@ double  PnlValue::dfGetValue( void )
 //*****************************************************************************
 // Get the spin control value including units as a string.
 //
-// Return Values:
+// Return Values :
 //   Success - The value as a string
 //   Failure - An empty string
 
@@ -663,7 +685,7 @@ const wxString & PnlValue::rosGetValue( void )
 //*****************************************************************************
 // Get the units.
 //
-// Return Values:
+// Return Values :
 //   Success - The currently selected units
 //   Failure - An empty string
 
@@ -683,7 +705,7 @@ const wxString & PnlValue::rosGetUnits( void )
 //*****************************************************************************
 // Spin button scroll event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtSpn - An object holding information about the event
 
 void  PnlValue::OnSpnScroll( wxSpinEvent & roEvtSpn )
@@ -752,14 +774,14 @@ void  PnlValue::OnSpnScroll( wxSpinEvent & roEvtSpn )
 //*****************************************************************************
 // Units choice box event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event
 
 void  PnlValue::OnChoUnits( wxCommandEvent & roEvtCmd )
 {
   if(      m_oChoUnits.eGetUnitsType( ) == eUNITS_TEMP )
   {
-         if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Deg C") ) )
+    if(      m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Deg C") ) )
       bSetParms( 27.0, -100.0, 200.0, 1.0 );
     else if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Deg F") ) )
       bSetParms( 70.0, -100.0, 400.0, 1.0 );
@@ -768,7 +790,7 @@ void  PnlValue::OnChoUnits( wxCommandEvent & roEvtCmd )
   }
   else if( m_oChoUnits.eGetUnitsType( ) == eUNITS_PHASE )
   {
-         if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Degree") ) )
+    if(      m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Degree") ) )
       bSetParms( 0.0, 0.0, 360.0, 1.0 );
     else if( m_oChoUnits.rosGetUnits( ).IsSameAs( wxT("Radian") ) )
       bSetParms( 0.0, 0.0, 6.3, 0.1 );
